@@ -163,7 +163,7 @@ def transform_data(
         for map in sheet_cache:
             if map["SOURCE"]:
                 transform_source_column(
-                    row_dict, map["API_FIELD"], tb_row, map["SOURCE"]
+                    row_dict, map["API_FIELD"], tb_row, map["SOURCE"], map["FUNC_TYPE"], map["FUNC_VAL"]
                 )
             else:
                 if map["FUNC_TYPE"] == "tbl":
@@ -196,11 +196,16 @@ def transform_data(
     return df
 
 
-def transform_source_column(map_row, map_col, tb_row, source_col):
+def transform_source_column(map_row, map_col, tb_row, source_col, func_type, func_value):
     """Reads the value from source table against source col, and maps it to map_col in map_row"""
     source = clean(source_col)
     if source in tb_row:
-        map_row[map_col] = str(tb_row[source])
+        if func_type == "truncate":
+            txt = str(tb_row[source])
+            func_value = int(func_value)
+            map_row[map_col] = txt[:func_value]
+        else:
+            map_row[map_col] = str(tb_row[source])
     else:
         raise TransformationError(
             "Field '{}' mentioned in mapping sheet is not found.".format(source)
@@ -251,11 +256,12 @@ def transform_function_column(map_row, map_col, tb_row, func_name, func_args):
     if func_name.strip().lower() == "div":
         data_values = func_args.split("|")
         with decimal.localcontext() as ctx:
-            if data_values[2] != "":
-                ctx.prec = int(data_values[2])
             result = decimal.Decimal(tb_row[clean(data_values[0])]) / decimal.Decimal(
                 clean(data_values[1])
             )
+            if data_values[2] != "":
+                result = round(result, int(data_values[2]))
+
     map_row[map_col] = result
 
 
